@@ -151,11 +151,19 @@ class Views(object):
                     content_type = '%s; charset=%s' % (format.content_type, settings.DEFAULT_CHARSET)
                 )
             except TemplateDoesNotExist:
-                response = HttpResponse(
-                    content = serializers.find(format)(context).serialize(request),
-                    content_type = '%s; charset=%s' % (format.content_type, settings.DEFAULT_CHARSET),
-                    status = status
-                )
+                try:
+                    response = HttpResponse(
+                        content = serializers.find(format)(context).serialize(request),
+                        content_type = '%s; charset=%s' % (format.content_type, settings.DEFAULT_CHARSET),
+                        status = status
+                    )
+                except serializers.UnknownSerializer:
+                    raise self.Error(
+                        'No template exists at %(template_path)s, and no serializer found for %(format)s' % {
+                            'template_path': template_path,
+                            'format': format
+                        }
+                    )
         else:
             response = HttpResponse(
                 content = serializers.find(format)(context).serialize(request),
@@ -167,3 +175,30 @@ class Views(object):
             response[header] = value
 
         return response
+
+    def _error(self, request, status, headers={}, prefix_template_path=False, **kwargs):
+        """
+        Convenience method to render an error response. The template is inferred from the status code.
+
+        :param request: A django.http.HttpRequest instance.
+        :param status: An integer describing the HTTP status code to respond with.
+        :param headers: A dictionary describing HTTP headers.
+        :param prefix_template_path: A boolean describing whether to prefix the template with the view's template path.
+        :param kwargs: Any additional keyword arguments to inject. These are wrapped under ``error`` for convenience.
+
+        For implementation details, see ``render``
+        """
+
+        return self._render(
+            request = request,
+            template = str(status),
+            status = status,
+            context = {
+                'error': kwargs
+            },
+            headers = headers,
+            prefix_template_path = prefix_template_path
+        )
+
+    class Error(Exception):
+        pass
